@@ -1,5 +1,5 @@
-#ifndef LOG_LEVELS_H__
-#define LOG_LEVELS_H__
+#ifndef __CR_LOG_LEVELS_H__
+#define __CR_LOG_LEVELS_H__
 
 #define LOG_MSG		(0) /* Print message regardless of log level */
 #define LOG_ERROR	(1) /* Errors only, when we're in trouble */
@@ -7,4 +7,6 @@
 #define LOG_INFO	(3) /* Informative, everything is fine */
 #define LOG_DEBUG	(4) /* Debug only */
 
-#endif /* LOG_LEVELS_H__ */
+#define DEFAULT_LOGLEVEL	LOG_WARN
+
+#endif /* __CR_LOG_LEVELS_H__ */
